#[=======================================================================[.rst:
ECMDebug
--------

Declare function to show debug messages for ECM modules and manupulate their indentation.

#]=======================================================================]

#[=======================================================================[.rst:
.. cmake:command:: ecm_debug

.. code-block:: cmake
   :caption: **Synopsys**

    ecm_debug(MESSAGE)

Print debug message if :cmake:variable:`MYVENDOR_ECM_DEBUG` variable is set.
It uses global :cmake:prop_gbl:`ECM_INDENT` property to obtain a current
intentation size.

#]=======================================================================]
function(ecm_debug msg)
    if(MYVENDOR_ECM_DEBUG)
        get_property(_ecm_indent GLOBAL PROPERTY ECM_INDENT)
        foreach(_c RANGE ${_ecm_indent})
            set(_ecm_indent_str "${_ecm_indent_str} ")
        endforeach()
        message(STATUS "[MyVendor-ECM]${_ecm_indent_str}${msg}")
    endif()
endfunction()

function(_ecm_debug_indent_init)
    get_property(_ecm_indent_is_set GLOBAL PROPERTY ECM_INDENT SET)
    if(NOT _ecm_indent_is_set)
        set_property(GLOBAL PROPERTY ECM_INDENT 1)
    endif()
endfunction()



#[=======================================================================[.rst:
.. cmake:command:: ecm_debug_indent

.. code-block:: cmake
   :caption: **Synopsys**

    ecm_debug_indent()

Increase global property :cmake:prop_gbl:`ECM_INDENT` to ``+2`` (spaces),
so further calls to :cmake:command:`ecm_debug` would print indented messages.

#]=======================================================================]
function(ecm_debug_indent)
    get_property(_ecm_indent GLOBAL PROPERTY ECM_INDENT)
    math(EXPR _ecm_indent "${_ecm_indent} + 2")
    set_property(GLOBAL PROPERTY ECM_INDENT ${_ecm_indent})
endfunction()


#[=======================================================================[.rst:
.. cmake:command:: ecm_debug_unindent

.. code-block:: cmake
   :caption: **Synopsys**

    ecm_debug_unindent()

Decrease global property :cmake:prop_gbl:`ECM_INDENT` to ``-2`` (spaces).

#]=======================================================================]
function(ecm_debug_unindent)
    get_property(_ecm_indent GLOBAL PROPERTY ECM_INDENT)
    math(EXPR _ecm_indent "${_ecm_indent} - 2")
    if(_ecm_indent LESS 1)
        set(_ecm_indent 1)
    endif()
    set_property(GLOBAL PROPERTY ECM_INDENT ${_ecm_indent})
endfunction()

_ecm_debug_indent_init()
